==> openbot-1.0.0-sources.jar: ai/engagely/openbot/model/constants/ServerConstants.kt <==
package ai.engagely.openbot.model.constants

object ServerConstants {
    const val GREETING_STYLE_OLD = "Old"
    const val GREETING_STYLE_NEW = "New"
    const val GREETING_STYLE_CAROUSAL = "Carousel"

    const val ENGAGEMENT_RESPONSE_TYPE_TEXT = "text"
    const val ENGAGEMENT_RESPONSE_TYPE_IMAGE = "image"
    const val ENGAGEMENT_RESPONSE_TYPE_VIDEO = "video"

    const val QUICK_MENU_POSITION_BOTTOM = "Bottom"
    const val QUICK_MENU_POSITION_LIST = "List"
    const val QUICK_MENU_POSITION_RIGHT = "Right"

    const val TOP_JOURNEY_STYLE_BUTTON = "Button"
    const val TOP_JOURNEY_STYLE_LIST = "List"

    const val GREETING_CAROUSAL_CLICK_TYPE_JOURNEY = "journey"
    const val GREETING_CAROUSAL_CLICK_TYPE_URL = "url"

    const val CHAT_ITEM_TYPE_PROCESS_TREE = "Process_Tree"
    const val CHAT_ITEM_TYPE_TEXT = "text"
    const val CHAT_ITEM_TYPE_CONFLICTS = "conflicts"
    const val CHAT_ITEM_TYPE_FAQ = "FAQ"
    const val CHAT_ITEM_TYPE_TABULAR_INFO = "tabular_info"

    const val CHAT_ITEM_DISPLAY_AS_BUTTON = "Button"

    const val CHAT_ITEM_RESPONSE_BY_BOT = "bot"
    const val CHAT_ITEM_RESPONSE_BY_USER = "user"

    const val CHAT_ITEM_QUERY_TYPE_BUTTON = "button"

    const val JOURNEY_DIALOGUE_RESPOND_TYPE_IMAGE = "Image"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_TEXT = "Text"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_CAROUSEL = "Carousel"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FORM = "Form"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FORM_TYPE_NORMAL = "Normal"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FORM_TYPE_CUSTOM = "Custom"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FILE = "File"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_URL = "URL"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_JOURNEY = "Journey"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_VIDEO = "Video"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_ADVANCED_URL = "Advanced URL"

    const val FAQ_RESPOND_TYPE_TEXT = "Text"
    const val FAQ_RESPOND_TYPE_IMAGE = "Image"
    const val FAQ_RESPOND_TYPE_VIDEO = "Video"
    const val FAQ_RESPOND_TYPE_FILE = "File"
    const val FAQ_RESPOND_TYPE_URL = "URL"
    const val FAQ_RESPOND_TYPE_CAROUSAL = "Carousel"
    const val FAQ_RESPOND_TYPE_JOURNEY = "Journey"

    const val VIDEO_TYPE_FILE = "file"
    const val VIDEO_TYPE_URL = "url"

    const val DIALOGUE_BUTTON_TYPE_JOURNEY = "journey"
    const val DIALOGUE_BUTTON_TYPE_URL = "URL"

    const val DIALOGUE_FORM_TYPE_TEXT = "text"
    const val DIALOGUE_FORM_TYPE_TEXT_AREA = "textarea"
    const val DIALOGUE_FORM_TYPE_RADIO = "radio"
    const val DIALOGUE_FORM_TYPE_CHECKBOX = "checkbox"
    const val DIALOGUE_FORM_TYPE_DATE = "date"
    const val DIALOGUE_FORM_TYPE_SELECT = "select"
    const val DIALOGUE_FORM_TYPE_FILE = "file"
    const val DIALOGUE_FORM_TYPE_BUTTON = "button"

    const val DIALOGUE_FORM_DATE_TYPE_FUTURE = "Future Date"
    const val DIALOGUE_FORM_DATE_TYPE_PAST = "Past Date"
    const val DIALOGUE_FORM_DATE_TYPE_TODAY = "Today's Date"

    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_TEXT = "text"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_NUMBER = "number"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_EMAIL = "email"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_PHONE_NUMBER = "tel"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_PASSWORD = "password"

    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_TEXT = "Text"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_IMAGE = "Image"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_VIDEO = "Video"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_FILE = "File"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_URL = "URL"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_CAROUSAL = "Carousel"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_JOURNEY = "Journey"
    const val TABULAR_INFO_DIALOGUE_RESPOND_POSITION_BEFORE = "before"
    const val TABULAR_INFO_DIALOGUE_RESPOND_POSITION_AFTER = "after"

    const val LIVE_CHAT_INPUT_TYPE_NO_FORM = "noForm"
    const val LIVE_CHAT_INPUT_TYPE_ID = "id"
    const val LIVE_CHAT_INPUT_TYPE_PHONE_NUMBER = "phone_number"
    const val LIVE_CHAT_INPUT_TYPE_EMAIL_ID = "email_id"
    const val LIVE_CHAT_INPUT_TYPE_DEFAULT_FORM = "default_form"
    const val LIVE_CHAT_INPUT_TYPE_FORM = "form"

    const val LIVE_CHAT_DISPLAY_FIELD_EMAIL = "Email"
    const val LIVE_CHAT_DISPLAY_FIELD_NAME = "Name"
}

==> openbot-1.0.1-sources.jar: ai/engagely/openbot/model/constants/ServerConstants.kt <==
package ai.engagely.openbot.model.constants

object ServerConstants {
    const val GREETING_STYLE_OLD = "Old"
    const val GREETING_STYLE_NEW = "New"
    const val GREETING_STYLE_CAROUSAL = "Carousel"

    const val ENGAGEMENT_RESPONSE_TYPE_TEXT = "text"
    const val ENGAGEMENT_RESPONSE_TYPE_IMAGE = "image"
    const val ENGAGEMENT_RESPONSE_TYPE_VIDEO = "video"

    const val QUICK_MENU_POSITION_BOTTOM = "Bottom"
    const val QUICK_MENU_POSITION_LIST = "List"
    const val QUICK_MENU_POSITION_RIGHT = "Right"

    const val TOP_JOURNEY_STYLE_BUTTON = "Button"
    const val TOP_JOURNEY_STYLE_LIST = "List"

    const val GREETING_CAROUSAL_CLICK_TYPE_JOURNEY = "journey"
    const val GREETING_CAROUSAL_CLICK_TYPE_URL = "url"

    const val CHAT_ITEM_TYPE_PROCESS_TREE = "Process_Tree"
    const val CHAT_ITEM_TYPE_TEXT = "text"
    const val CHAT_ITEM_TYPE_CONFLICTS = "conflicts"
    const val CHAT_ITEM_TYPE_FAQ = "FAQ"
    const val CHAT_ITEM_TYPE_TABULAR_INFO = "tabular_info"
    const val CHAT_ITEM_TYPE_LIVE_CHAT_CONNECTED = "live_connected"
    const val CHAT_ITEM_TYPE_LIVE_CHAT_DISCONNECTED = "live_disconnect"
    const val CHAT_ITEM_TYPE_LIVE_CHAT_MEDIA = "media"

    const val CHAT_ITEM_DISPLAY_AS_BUTTON = "Button"

    const val CHAT_ITEM_RESPONSE_BY_BOT = "bot"
    const val CHAT_ITEM_RESPONSE_BY_USER = "user"

    const val CHAT_ITEM_QUERY_TYPE_BUTTON = "button"

    const val JOURNEY_DIALOGUE_RESPOND_TYPE_IMAGE = "Image"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_TEXT = "Text"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_CAROUSEL = "Carousel"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FORM = "Form"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FORM_TYPE_NORMAL = "Normal"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FORM_TYPE_CUSTOM = "Custom"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_FILE = "File"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_URL = "URL"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_JOURNEY = "Journey"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_VIDEO = "Video"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_ADVANCED_URL = "Advanced URL"
    const val JOURNEY_DIALOGUE_RESPOND_TYPE_SEND_TO_LIVE = "Send to Live"

    const val FAQ_RESPOND_TYPE_TEXT = "Text"
    const val FAQ_RESPOND_TYPE_IMAGE = "Image"
    const val FAQ_RESPOND_TYPE_VIDEO = "Video"
    const val FAQ_RESPOND_TYPE_FILE = "File"
    const val FAQ_RESPOND_TYPE_URL = "URL"
    const val FAQ_RESPOND_TYPE_CAROUSAL = "Carousel"
    const val FAQ_RESPOND_TYPE_JOURNEY = "Journey"

    const val VIDEO_TYPE_FILE = "file"
    const val VIDEO_TYPE_URL = "url"

    const val DIALOGUE_BUTTON_TYPE_JOURNEY = "journey"
    const val DIALOGUE_BUTTON_TYPE_URL = "URL"

    const val DIALOGUE_FORM_TYPE_TEXT = "text"
    const val DIALOGUE_FORM_TYPE_TEXT_AREA = "textarea"
    const val DIALOGUE_FORM_TYPE_RADIO = "radio"
    const val DIALOGUE_FORM_TYPE_CHECKBOX = "checkbox"
    const val DIALOGUE_FORM_TYPE_DATE = "date"
    const val DIALOGUE_FORM_TYPE_SELECT = "select"
    const val DIALOGUE_FORM_TYPE_FILE = "file"
    const val DIALOGUE_FORM_TYPE_BUTTON = "button"

    const val DIALOGUE_FORM_DATE_TYPE_FUTURE = "Future Date"
    const val DIALOGUE_FORM_DATE_TYPE_PAST = "Past Date"
    const val DIALOGUE_FORM_DATE_TYPE_TODAY = "Today's Date"

    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_TEXT = "text"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_NUMBER = "number"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_EMAIL = "email"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_PHONE_NUMBER = "tel"
    const val DIALOGUE_FORM_TEXT_FIELD_TYPE_PASSWORD = "password"

    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_TEXT = "Text"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_IMAGE = "Image"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_VIDEO = "Video"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_FILE = "File"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_URL = "URL"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_CAROUSAL = "Carousel"
    const val TABULAR_INFO_DIALOGUE_RESPOND_TYPE_JOURNEY = "Journey"
    const val TABULAR_INFO_DIALOGUE_RESPOND_POSITION_BEFORE = "before"
    const val TABULAR_INFO_DIALOGUE_RESPOND_POSITION_AFTER = "after"

    const val LIVE_CHAT_INPUT_TYPE_NO_FORM = "noForm"
    const val LIVE_CHAT_INPUT_TYPE_ID = "id"
    const val LIVE_CHAT_INPUT_TYPE_PHONE_NUMBER = "phone_number"
    const val LIVE_CHAT_INPUT_TYPE_EMAIL_ID = "email_id"
    const val LIVE_CHAT_INPUT_TYPE_DEFAULT_FORM = "default_form"
    const val LIVE_CHAT_INPUT_TYPE_FORM = "form"

    const val LIVE_CHAT_DISPLAY_FIELD_EMAIL = "Email"
    const val LIVE_CHAT_DISPLAY_FIELD_NAME = "Name"

    const val LIVE_CHAT_RESPONSE_TYPE_AGENTS_READY = "agent_team"
    const val LIVE_CHAT_RESPONSE_TYPE_AGENTS_QUEUED = "live_agents_queued"
    const val LIVE_CHAT_RESPONSE_TYPE_AGENT_CONNECTED = "live_connected"
    const val LIVE_CHAT_RESPONSE_TYPE_AGENT_DISCONNECTED = "live_disconnect"
    const val LIVE_CHAT_RESPONSE_TYPE_AGENTS_UNAVAILABLE = "live_agents_unavailable"
    const val LIVE_CHAT_RESPONSE_TYPE_MEDIA = "media"

    const val LIVE_CHAT_RESPONSE_BY_CLIENT = "client"
    const val LIVE_CHAT_RESPONSE_BY_LIVE_AGENT = "liveagent"
    const val LIVE_CHAT_RESPONSE_BY_USER = "user"
}
